==> operations-orchestration-api-1.1.2.tgz: package/test.js <==
'use strict'

var options = {
	username: 'admin',
	password: 'admin',
	baseUrl: 'http://myd-vm03021.hpswlabs.adapps.hp.com:8050/oo/rest/v1'
};

var OO = require('./index');
OO.setClient(options);

// OO.dashboard.statistics(function(err, body) {
// 	console.log(err);
// 	console.log(body);
// });

/*
				'flowUuid': '0a8f3175-d71e-4426-b578-1ace1fe1d898',
				'flowScheduleName':'Scheduled Flow Created By REST',
				'triggerExpression':'* * * * *',
				'runLogLevel': 'DEBUG',
				'inputs': {
					'host': '127.0.0.1',
					'port': '22',
					'username': 'root',
					'password': 'root',
					'protocol': 'ssh',
					'command': 'ps',

*/

var flow = {
				'flowUuid': '0a8f3175-d71e-4426-b578-1ace1fe1d898',
				'flowScheduleName': 'Scheduled Flow Created By REST 2',
				'triggerExpression': '* 10 10 * * *',
				'runLogLevel': 'DEBUG',
				"startDate": '1314079869000',
				"username": 'admin',
				"inputPromptUseBlank": true,
				"timeZone": "Asia/Amman",
				'inputs': {
					'host': '127.0.0.1',
					'port': '22',
					'username': 'root',
					'password': 'root',
					'protocol': 'ssh',
					'command': 'ps',
				}
			};

OO.schedules.scheduleFlow(flow, function(err, body) {
	console.log(err);
	console.log(body);
});


/*
var configItem = {
	type: 'group-aliases',
    path: 'RAS_Operator_Path',
    value: 'RAS_Operator_Path',
};

OO.config.setItem(configItem, function(err, body) {
	console.log(err);
	console.log(body);
});

OO.config.getAllItems(function(err, body) {
	console.log(err);
	console.log(body);
});
*/

==> operations-orchestration-api-1.1.3.tgz: package/test.js <==
'use strict'

var options = {
	username: 'admin',
	password: 'admin',
	//baseUrl: 'http://myd-vm03021.hpswlabs.adapps.hp.com:8050/oo/rest/v1'
	baseUrl: 'https://16.60.202.133:8443/oo/rest/v1'
};

var OO = require('./index');
OO.setClient(options);

// OO.dashboard.statistics(function(err, body) {
// 	console.log(err);
// 	console.log(body);
// });

/*
				'flowUuid': '0a8f3175-d71e-4426-b578-1ace1fe1d898',
				'flowScheduleName':'Scheduled Flow Created By REST',
				'triggerExpression':'* * * * *',
				'runLogLevel': 'DEBUG',
				'inputs': {
					'host': '127.0.0.1',
					'port': '22',
					'username': 'root',
					'password': 'root',
					'protocol': 'ssh',
					'command': 'ps',

*/

var flow = {
				'flowUuid': '0a8f3175-d71e-4426-b578-1ace1fe1d898',
				'flowScheduleName': 'Scheduled Flow Created By REST 2',
				'triggerExpression': '* 10 10 * * *',
				'runLogLevel': 'DEBUG',
				"startDate": '1314079869000',
				"username": 'admin',
				"inputPromptUseBlank": true,
				"timeZone": "Asia/Amman",
				'inputs': {
					'host': '127.0.0.1',
					'port': '22',
					'username': 'root',
					'password': 'root',
					'protocol': 'ssh',
					'command': 'ps',
				}
			};

// OO.schedules.scheduleFlow(flow, function(err, body) {
// 	console.log(err);
// 	console.log(body);
// });



var configItem1 = {
	type: 'group-aliases',
    path: 'RAS_Operator_Path',
    value: 'RAS_Operator_Path',
};

var configItem2 = {
	type: 'system-properties',
    path: 'io.cloudslang.base.from',
    value: 'ZZZ',
};



OO.config.setItem(configItem1, function(err, body) {
	console.log(err);
	console.log(body);
});

OO.config.setItem(configItem2, function(err, body) {
	console.log(err);
	console.log(body);
});

// OO.config.getAllItems(function(err, body) {
// 	console.log(err);
// 	console.log(body);
// });
